@@ -51,6 +51,26 @@ async def test_map_field_double_nested_expression_jmespath():
     )
 
 
+@pytest.mark.asyncio
+async def test_map_field_nested_expression_jmespath_object():
+    block = Block(properties={"language": "jmespath",
+                              "expression": {"new_field": "`hello`", "name" : "details.fname"}})
+    block.init()
+    assert await block.run([{"details": {"fname": "john", "lname": "doe"}}]) == utils.all_success([
+        {"new_field": "hello", "name": "john"}]
+    )
+
+
+@pytest.mark.asyncio
+async def test_map_field_double_nested_expression_jmespath_object():
+    block = Block(properties={"language": "jmespath",
+                              "expression": {"new_field": "`hello`", "name" : "details.name.fname"}})
+    block.init()
+    assert await block.run([{"details": {"name": {"fname": "john", "lname": "doe"}, "country": "israel"}}]) == utils.all_success([
+        {"new_field": "hello", "name": "john"}]
+    )
+
+
 @pytest.mark.asyncio
 async def test_map_expression_non_quoted_jmespath():
     block = Block(properties={"language": "jmespath",
